@@ -39,6 +39,7 @@ pub struct Termusic {
     pub music_dir_from_cli: Option<String>,
     pub loop_mode: Loop,
     pub volume: i32,
+    pub speed: f32,
     pub add_playlist_front: bool,
     pub disable_exit_confirmation: bool,
     pub playlist_display_symbol: bool,
@@ -55,6 +56,7 @@ impl Default for Termusic {
             music_dir_from_cli: None,
             loop_mode: Loop::Queue,
             volume: 70,
+            speed: 1.0,
             add_playlist_front: false,
             disable_exit_confirmation: false,
             playlist_display_symbol: true,
