@@ -36,6 +36,7 @@ pub struct Player {
     total_duration: Option<Duration>,
     volume: u16,
     safe_guard: bool,
+    speed: f32,
 }
 impl Default for Player {
     fn default() -> Self {
@@ -43,6 +44,8 @@ impl Default for Player {
         let sink = Sink::try_new(&handle).unwrap();
         let volume = 50;
         sink.set_volume(f32::from(volume) / 100.0);
+        let speed = 1.0;
+        sink.set_speed(1.0);
 
         Self {
             _stream: stream,
@@ -51,6 +54,7 @@ impl Default for Player {
             total_duration: None,
             volume,
             safe_guard: true,
+            speed,
         }
     }
 }
@@ -85,9 +89,10 @@ impl Player {
         let decoder = Decoder::new_decoder(BufReader::new(file)).unwrap();
         self.total_duration = decoder.total_duration();
         self.sink.append(decoder);
+        self.sink.set_speed(self.speed);
     }
     pub fn stop(&mut self) {
-        self.sink.destroy();
+        // self.sink.destroy();
         self.sink = Sink::try_new(&self.handle).unwrap();
         self.sink.set_volume(f32::from(self.volume) / 100.0);
     }
@@ -155,6 +160,11 @@ impl Player {
     pub const fn volume_percent(&self) -> u16 {
         self.volume
     }
+
+    pub fn set_speed(&mut self, speed: f32) {
+        self.speed = speed;
+        self.sink.set_speed(speed);
+    }
 }
 
 impl GeneralP for Player {
@@ -224,4 +234,29 @@ impl GeneralP for Player {
         }
         Ok((percent, position, duration))
     }
+
+    fn speed_up(&mut self) {
+        let mut speed = self.speed + 0.1;
+        if speed > 3.0 {
+            speed = 3.0;
+        }
+        self.set_speed(speed);
+    }
+
+    fn speed_down(&mut self) {
+        let mut speed = self.speed - 0.1;
+        if speed < 0.1 {
+            speed = 0.1;
+        }
+        self.set_speed(speed);
+    }
+
+    fn set_speed(&mut self, speed: f32) {
+        self.speed = speed;
+        self.set_speed(speed);
+    }
+
+    fn speed(&self) -> f32 {
+        self.speed
+    }
 }
