@@ -1,11 +1,11 @@
-use std::io::{Read, Seek};
-use std::marker::Sync;
+// use std::io::{Read, Seek};
+// use std::marker::Sync;
 use std::sync::{Arc, Weak};
 use std::{error, fmt};
 
 use super::decoder;
 use super::dynamic_mixer::{self, DynamicMixerController};
-use super::sink::Sink;
+// use super::sink::Sink;
 use super::source::Source;
 use cpal::traits::{DeviceTrait, HostTrait, StreamTrait};
 use cpal::Sample;
@@ -78,16 +78,16 @@ impl OutputStreamHandle {
         Ok(())
     }
 
-    /// Plays a sound once. Returns a `Sink` that can be used to control the sound.
-    pub fn play_once<R>(&self, input: R) -> Result<Sink, PlayError>
-    where
-        R: Read + Seek + Send + Sync + 'static,
-    {
-        let input = decoder::Decoder::new_decoder(input)?;
-        let sink = Sink::try_new(self)?;
-        sink.append(input);
-        Ok(sink)
-    }
+    // Plays a sound once. Returns a `Sink` that can be used to control the sound.
+    // pub fn play_once<R>(&self, input: R) -> Result<Sink, PlayError>
+    // where
+    //     R: Read + Seek + Send + Sync + 'static,
+    // {
+    //     let input = decoder::Decoder::new_decoder(input)?;
+    //     let sink = Sink::try_new(self)?;
+    //     sink.append(input);
+    //     Ok(sink)
+    // }
 }
 
 /// An error occurred while attemping to play a sound.
