@@ -34,7 +34,7 @@ use std::ffi::OsStr;
 use std::fs::rename;
 use std::fs::File;
 use std::io::BufReader;
-use std::path::Path;
+use std::path::{Path, PathBuf};
 use std::str::FromStr;
 use std::time::Duration;
 
@@ -59,6 +59,7 @@ pub struct Song {
     lyric_selected_index: usize,
     parsed_lyric: Option<Lyric>,
     picture: Option<Picture>,
+    album_photo: Option<String>,
     file_type: Option<FileType>,
 }
 
@@ -127,6 +128,25 @@ impl Song {
             }
         }
 
+        let mut parent_folder: PathBuf = PathBuf::new();
+
+        if path.is_dir() {
+            parent_folder = path.to_path_buf();
+        } else if let Some(parent) = path.parent() {
+            parent_folder = parent.to_path_buf();
+        };
+
+        if let Ok(files) = std::fs::read_dir(&parent_folder) {
+            for f in files.flatten() {
+                let path = f.path();
+                if let Some(extension) = path.extension() {
+                    if extension == "jpg" || extension == "png" {
+                        song.album_photo = Some(path.to_string_lossy().to_string());
+                    }
+                }
+            }
+        }
+
         Ok(song)
     }
 
@@ -145,6 +165,7 @@ impl Song {
         let parsed_lyric: Option<Lyric> = None;
         let lyric_frames: Vec<Lyrics> = Vec::new();
         let picture: Option<Picture> = None;
+        let album_photo: Option<String> = None;
         Self {
             ext,
             file_type: None,
@@ -158,6 +179,7 @@ impl Song {
             lyric_frames,
             lyric_selected_index: 0,
             picture,
+            album_photo,
         }
     }
 
@@ -248,6 +270,12 @@ impl Song {
             None => None,
         }
     }
+    pub fn album_photo(&self) -> Option<&str> {
+        match self.album_photo.as_ref() {
+            Some(a) => Some(a),
+            None => None,
+        }
+    }
 
     /// Optionally return the artist of the song
     /// If `None` it wasn't able to read the tags
