@@ -1,6 +1,9 @@
 use crate::player::GeneralP;
 use crate::song::Song;
-use crate::ui::{Id, Model, Msg, Status};
+// use crate::ui::Status;
+use crate::ui::{Id, Model, Msg};
+// use std::thread::{self, sleep};
+// use std::thread::sleep;
 
 use crate::ui::components::StyleColorSymbol;
 use if_chain::if_chain;
@@ -71,8 +74,8 @@ impl Model {
             let artist = song.artist().unwrap_or("Unknown Artist");
             let title = song.title().unwrap_or("Unknown Title");
             let progress_title = format!(
-                "Playing: {:^.20} - {:^.20} | Volume: {}",
-                            artist, title, self.config.volume
+                "Playing: {:^.20} - {:^.20} | Volume: {} | Speed: {:^.1} ",
+                            artist, title, self.config.volume, self.config.speed,
                 );
             then {
                 self.app.attr( &Id::Progress,
@@ -92,21 +95,16 @@ impl Model {
                 return;
             }
 
-            if let Some(Status::Paused) = self.status {
-                if let Some(t) = std::time::Instant::now()
-                    .checked_sub(std::time::Duration::from_secs(time_pos.try_into().unwrap()))
-                {
-                    self.time_pos_elapsed = t;
-                }
+            if time_pos >= duration {
+                // std::thread::sleep(Duration::from_millis(500));
+                // println!("{}--{}", time_pos, duration);
+                // self.status = Some(Status::Stopped);
+                self.player_next();
                 return;
             }
 
             self.time_pos = time_pos;
 
-            if self.time_pos_elapsed.elapsed().as_secs() > duration as u64 {
-                self.status = Some(Status::Stopped);
-                return;
-            }
             let new_prog = Self::progress_safeguard(progress);
             self.progress_set(new_prog, duration);
         }
