@@ -62,6 +62,8 @@ pub enum Msg {
     PlayerTogglePause,
     PlayerVolumeUp,
     PlayerVolumeDown,
+    PlayerSpeedUp,
+    PlayerSpeedDown,
     PlayerSeek(isize),
     Playlist(PLMsg),
     QuitPopupCloseCancel,
@@ -253,6 +255,14 @@ pub enum KEMsg {
     GlobalPlayerSeekBackwardBlurUp,
     GlobalPlayerSeekBackwardInputBlurDown,
     GlobalPlayerSeekBackwardInputBlurUp,
+    GlobalPlayerSpeedUpBlurDown,
+    GlobalPlayerSpeedUpBlurUp,
+    GlobalPlayerSpeedUpInputBlurDown,
+    GlobalPlayerSpeedUpInputBlurUp,
+    GlobalPlayerSpeedDownBlurDown,
+    GlobalPlayerSpeedDownBlurUp,
+    GlobalPlayerSpeedDownInputBlurDown,
+    GlobalPlayerSpeedDownInputBlurUp,
     GlobalPlayerTogglePauseBlurDown,
     GlobalPlayerTogglePauseBlurUp,
     GlobalPlayerTogglePauseInputBlurDown,
@@ -438,6 +448,10 @@ pub enum IdKeyEditor {
     GlobalPlayerSeekForwardInput,
     GlobalPlayerSeekBackward,
     GlobalPlayerSeekBackwardInput,
+    GlobalPlayerSpeedUp,
+    GlobalPlayerSpeedUpInput,
+    GlobalPlayerSpeedDown,
+    GlobalPlayerSpeedDownInput,
     GlobalQuit,
     GlobalQuitInput,
     GlobalRight,
